/////////////////////////////////////////////////////////////////////////////////////
// File:	html_reg_page.h
// Author:	Walt Jones
// Email:	wjones@blarg.net
// Date:	8 August, 2000
// Project:	ResNet Autoreg v2.0
// Purpose:	Provides HTML code for the primary registration site
/////////////////////////////////////////////////////////////////////////////////////

// Make sure this file is included only once
#if !defined( HTML_REG_PAGES_H )
#define HTML_REG_PAGES_H

#define stdResNetError "Please contact the ResNet office with the above error message in person (McIntyre 011J), by phone (x8570) or by Email (<A HREF=mailto:resnet@ups.edu>resnet@ups.edu</A>)"

#include <string>
#include <vector>
#include <stdlib.h>
#include "cgiinterface.h"
#include "stringfunc.h"
#include "configfile.h"
#include "conf.h"

void showHTMLregErrorPage(cgiInterface &webI, const string &title, const string &message, const string &extMessage = "");
void showHTMLregInitialPage(cgiInterface &webI, const string &errorMsg, const string &username, const string &os, const string &man, const string &sys, const string &nic);
void showHTMLregAgreePage(cgiInterface &webI, const int userID, const string &username, const string &macAddr, const string &hostname, const string &os, const string &man, const string &system, const string &nic, const int &cost);
void showHTMLregSuccessPage(cgiInterface &webI, const string &username);
void showHTMLregFinishedPage(cgiInterface &webI);

void showHTMLregErrorPage(cgiInterface &webI, const string &title, const string &message, const string &extMessage)
{
	configFileInterface aregconf(CONF_FILE);
	string error_logFile;
	string username;
	string IPaddr;
		
	// Get ERROR_LOG
	if (aregconf.open() == configFileSuccess)
	{
		if (aregconf.getERROR_LOG(error_logFile) == configFileSuccess)
		{
			webI.getFormStringNoNewlines("username", username);
			IPaddr = webI.getRemoteAddr();
			if (username.length() == 0)
				username = "unknown";
			
			errorLogInterface errorLog(error_logFile.c_str());
			errorLog.addEntry("[" + IPaddr + "] [" + username + "] " + message);
		}
		aregconf.close();
	}
	
	
	webI.printHeaderContentType("text/html");
	webI.printLn("<HTML>");
	webI.printLn("<HEAD>");
	webI.printLn("<TITLE>Online Machine Registration</TITLE>");
	webI.printLn("</HEAD>");
	webI.printLn("<BODY TEXT=#000000 BGCOLOR=#ffffff LINK=#0000ee VLINK=#551a8b ALINK=#ff0000>");
	webI.printLn("<CENTER>");
	webI.printLn("<IMG SRC=/images/resnetlogo.gif ALT=\"UPS ResNet\" ALIGN=TEXTTOP>");
	webI.printLn("</CENTER><BR><BR>");
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE WIDTH=600>");
	webI.printLn("<TR><TD>");
	webI.printLn("<CENTER><FONT SIZE=+2><B>" + title + "</B></FONT></CENTER><BR>");
	webI.printLn("<CENTER><FONT SIZE=+1><B>" + message + "</B></FONT></CENTER><BR><BR>");
	webI.printLn("</TD></TR>");
	if (extMessage.length() > 0)
	{		
		webI.printLn("<TR><TD>");
		webI.printLn("<CENTER><B>" + extMessage + "</B></CENTER>");
		webI.printLn("</TD></TR>");
	}
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	webI.printLn("</BODY>");
	webI.printLn("</HTML>");
	exit(1);
}

void showHTMLregInitialPage(cgiInterface &webI, const string &errorMsg = "", const string &username = "", const string &os = "", const string &man = "", const string &sys = "", const string &nic = "")
{
	configFileInterface aregconf(CONF_FILE);
	vector<string> OSchoice;
	vector<string> MANchoice;
	vector<string> SYSchoice;
	vector<string> NICchoice;
		
	// Get OS, MAN, SYS and NIC choices
	if (aregconf.open() != configFileSuccess)
		showHTMLregErrorPage(webI, "Configuration File Not Found", "The file " + string(CONF_FILE) + " could not be found", stdResNetError);
	if ((aregconf.getOSchoices(OSchoice) != configFileSuccess)||(aregconf.getMANchoices(MANchoice) != configFileSuccess)||
		(aregconf.getNICchoices(NICchoice) != configFileSuccess))
		showHTMLregErrorPage(webI, "Configuration File Read Error", "The file " + string(CONF_FILE) + " did not contain the OS, MAN or NIC choice information necessary to continue", stdResNetError);
	aregconf.close();
	SYSchoice.push_back("Tower");
	SYSchoice.push_back("Desktop");
	SYSchoice.push_back("Laptop");

	// Show the initial registration page
	webI.printHeaderContentType("text/html");
	webI.printLn("<HTML>");
	webI.printLn("<HEAD>");
	webI.printLn("<TITLE>Online Machine Registration</TITLE>");
	webI.printLn("<SCRIPT LANGUAGE=Javascript>");
	webI.printFile("regpage.js");
	webI.printLn("</SCRIPT>");
	webI.printLn("</HEAD>");
	webI.printLn("<BODY TEXT=#000000 BGCOLOR=#ffffff LINK=#0000ee VLINK=#551a8b ALINK=#ff0000 ONLOAD=\"document.regForm.username.focus()\">");
	webI.printLn("<FORM action=register method=post name=regForm ONSUBMIT=\"return (validateForm())\">");
	webI.printLn("<INPUT TYPE=HIDDEN NAME=sessionvars VALUE=AUTH>");
	webI.printLn("<CENTER>");
	webI.printLn("<IMG SRC=/images/resnetlogo.gif ALT=\"UPS ResNet\" ALIGN=TEXTTOP>");
	webI.printLn("</CENTER>");
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE WIDTH=600>");
	webI.printLn("<TR><TD>");
	webI.printLn("<CENTER>");
	webI.printLn("<B><FONT COLOR=#7b3139 SIZE=+2>Welcome to UPS ResNet!</FONT><BR>");
	webI.printLn("In order to obtain access to the campus network and the internet, you must first register ");
	webI.printLn("your machine with ResNet. Your ResNet account allows you to register only one machine. Should ");
	webI.printLn("you need to register additional machines, you will need to contact the ResNet Office. For more ");
	webI.printLn("information, click <A href=/help/help.html>here</A>.</B>");
	webI.printLn("</CENTER>");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	if (errorMsg.length() > 0)
	{
		webI.printLn("<CENTER>");
		webI.printLn("<TABLE BORDER=1 CELLSPACING=0 WIDTH=600>");
		webI.printLn("<TR><TD>");
		webI.printLn("<TABLE WIDTH=100%%>");
		webI.printLn("<TR><TD>");
		webI.printLn("<IMG SRC=/images/error.gif BORDER=0 align=ABSCENTER> ");
		webI.printLn("</TD><TD WIDTH=100%%>");
		webI.printLn("<FONT SIZE=-1><B>" + errorMsg + "</B></FONT>");
		webI.printLn("</TD></TR>");
		webI.printLn("</TABLE>");
		webI.printLn("</TD></TR>");
		webI.printLn("</TABLE>");
		webI.printLn("</CENTER>");
	}
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE CELLSPACING=0 CELLPADDING=5 WIDTH=400>");
	webI.printLn("<TR><TD>");
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE BORDER=1 CELLSPACING=0 CELLPADDING=5 WIDTH=100%% bgcolor=#7b3139>");
	webI.printLn("<TR><TD VALIGN=top>");
	webI.printLn("<CENTER>");
	webI.printLn("<FONT COLOR=#ffffff><B>ResNet Information</B></FONT>");
	webI.printLn("<HR NOSHADE WIDTH=100%%>");
	webI.printLn("</CENTER>");
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE CELLSPACING=0 CELLPADDING=0>");
	webI.printLn("<TR><TD>");
	webI.printLn("<B><TT><FONT COLOR=#ffffff SIZE=+1>Username: </FONT></TT></B>");
	webI.printLn("<INPUT TYPE=text name=username value=\"" + username + "\"size=15 maxlength=32><BR>");
	webI.printLn("<B><TT><FONT COLOR=#ffffff SIZE=+1>Password: </FONT></TT></B>");
	webI.printLn("<INPUT type=password name=passwd size=15 maxlength=20> ");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE CELLSPACING=0 CELLPADDING=5 WIDTH=400>");
	webI.printLn("<TR><TD>");
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE BORDER=1 CELLSPACING=0 CELLPADDING=5 WIDTH=100%% BGCOLOR=#7b3139>");
	webI.printLn("<TR><TD VALIGN=top>");
	webI.printLn("<CENTER>");
	webI.printLn("<B><FONT COLOR=#ffffff>System Information</FONT></B>");
	webI.printLn("<HR NOSHADE WIDTH=100%%>");
	webI.printLn("</CENTER>");
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE CELLSPACING=0 CELLPADDING=0>");
	webI.printLn("<TR><TD>");
	webI.printLn("<B><TT><FONT COLOR=#ffffff SIZE=+1>OS: </FONT></TT></B>");
	webI.printLn("<SELECT NAME=os>");
	webI.printLn("<OPTION>Specify your OS");
	webI.printSelect(OSchoice, os);
	webI.printLn("</SELECT><BR>");
	webI.printLn("<B><TT><FONT COLOR=#ffffff SIZE=+1>Manufacturer: </FONT></TT></B>");
	webI.printLn("<SELECT NAME=man>");
	webI.printLn("<OPTION>Specify your manufacturer");
	webI.printSelect(MANchoice, man);
	webI.printLn("</SELECT><BR>");
	webI.printLn("<B><TT><FONT COLOR=#ffffff SIZE=+1>System: </FONT></TT></B>");
	webI.printLn("<SELECT NAME=system>");
	webI.printLn("<OPTION>Specify your machine type");
	webI.printSelect(SYSchoice, sys);
	webI.printLn("</SELECT><BR>");
	webI.printLn("<B><TT><FONT COLOR=#ffffff SIZE=+1>Card: </FONT></TT></B>");
	webI.printLn("<SELECT NAME=nic>");
	webI.printLn("<OPTION>Specify your network card");
	webI.printSelect(NICchoice, nic);
	webI.printLn("</SELECT><BR>");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE CELLSPACING=0 CELLPADDING=5 WIDTH=400>");
	webI.printLn("<TR><TD VALIGN=TOP>");
	webI.printLn("<CENTER>");
	webI.printLn("<INPUT TYPE=SUBMIT VALUE=Register>");
	webI.printLn("</CENTER>");
	webI.printLn("<CENTER>");
	webI.printLn("<FONT SIZE=-1>By pressing the \"Register\" button, you are certifying that the information you ");
	webI.printLn("have entered is correct. You may notice some lag if there is another registration in process. ");
	webI.printLn("Please be patient.</FONT><BR>");
	webI.printLn("</CENTER>");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</FORM>");
	webI.printLn("</BODY>");
	webI.printLn("</HTML>");
	exit(0);
}

void showHTMLregAgreePage(cgiInterface &webI, const int userID, const string &username, const string &macAddr, const string &hostname, const string &os, const string &man, const string &system, const string &nic, const int &cost)
{
	configFileInterface aregconf(CONF_FILE);
	string policyFile;
	
	// Get the location of the policy file
	if (aregconf.open() != configFileSuccess)
		showHTMLregErrorPage(webI, "Configuration File Not Found", "The file " + string(CONF_FILE) + " could not be found", stdResNetError);
	if (aregconf.getPOLICY(policyFile) != configFileSuccess)
		showHTMLregErrorPage(webI, "Configuration File Read Error", "The file " + string(CONF_FILE) + " did not contain the policy file information necessary to continue", stdResNetError);
	aregconf.close();

	// Show the agreement page
	webI.printHeaderContentType("text/html");
	webI.printLn("<HTML>");
	webI.printLn("<HEAD>");
	webI.printLn("<TITLE>Online Machine Registration</TITLE>");
	webI.printLn("</HEAD>");
	webI.printLn("<BODY TEXT=#000000 BGCOLOR=#ffffff LINK=#0000ee VLINK=#551a8b ALINK=#ff0000>");
	webI.printLn("<FORM action=register method=post name=regForm>");
	webI.printLn("<INPUT TYPE=HIDDEN NAME=sessionvars VALUE=REG>");
	webI.printLn("<INPUT TYPE=HIDDEN NAME=OIS_ID VALUE=" + itostr(userID, 10) + ">");
	webI.printLn("<INPUT TYPE=HIDDEN NAME=username VALUE=" + username + ">");
	webI.printLn("<INPUT TYPE=HIDDEN NAME=macAddr VALUE=\"" + macAddr + "\">");
	webI.printLn("<INPUT TYPE=HIDDEN NAME=hostname VALUE=\"" + hostname + "\">");
	webI.printLn("<INPUT TYPE=HIDDEN NAME=os VALUE=\"" + os + "\">");
	webI.printLn("<INPUT TYPE=HIDDEN NAME=system VALUE=\"" + system + "\">");
	webI.printLn("<INPUT TYPE=HIDDEN NAME=man VALUE=\"" + man + "\">");
	webI.printLn("<INPUT TYPE=HIDDEN NAME=nic VALUE=\"" + nic + "\">");
	webI.printLn("<CENTER>");
	webI.printLn("<IMG SRC=/images/resnetlogo.gif ALT=\"UPS ResNet\" ALIGN=TEXTTOP>");
	webI.printLn("</CENTER>");
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE WIDTH=600>");
	webI.printLn("<TR><TD>");
	webI.printLn("<CENTER>");
	webI.printLn("<B>Before completing registration, you must acknowledge your agreement with the ResNet ");
	webI.printLn("Acceptable Use Policy and the University's Computer and Network Acceptable Use Policy. ");
	webI.printLn("Pressing the \"I Agree\" button also signifies that you understand that you will be charged ");
	webI.printLn("$" + itostr(cost, 10) + " for each semester you use the ResNet service.  Unless you contact our office directly, ");
	webI.printLn("ResNet charges will also automatically be placed on your account for the spring term.</B><BR><BR>");
	webI.printLn("<TEXTAREA ROWS=20 COLS=65 WRAP=PHYSICAL ONFOCUS=\"this.blur()\">");
	webI.printFile(policyFile.c_str());
	webI.printLn("</TEXTAREA><BR><BR>");
	webI.printLn("<INPUT TYPE=SUBMIT NAME=agree VALUE=\"I Agree\"> <INPUT TYPE=BUTTON NAME=cancel VALUE=\"I Do Not Agree\" ONCLICK=\"window.close()\"><BR>");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	webI.printLn("</FORM>");
	webI.printLn("</BODY>");
	webI.printLn("</HTML>");
	
	exit(0);
}

void showHTMLregSuccessPage(cgiInterface &webI, const string &username)
{
	// Show the success page
	webI.printHeaderContentType("text/html");
	webI.printLn("<HTML>");
	webI.printLn("<HEAD>");
	webI.printLn("<TITLE>Online Machine Registration</TITLE>");
	webI.printLn("</HEAD>");
	webI.printLn("<BODY TEXT=#000000 BGCOLOR=#ffffff LINK=#0000ee VLINK=#551a8b ALINK=#ff0000 ONLOAD=\"setTimeout('document.regForm.submit()', 60000)\">");
	webI.printLn("<FORM action=register method=post name=regForm>");
	webI.printLn("<INPUT TYPE=HIDDEN NAME=sessionvars VALUE=COMPLETE>");
	webI.printLn("<CENTER>");
	webI.printLn("<IMG SRC=/images/resnetlogo.gif ALT=\"UPS ResNet\" ALIGN=TEXTTOP>");
	webI.printLn("</CENTER>");
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE WIDTH=500>");
	webI.printLn("<TR><TD>");
	webI.printLn("<CENTER>");
	webI.printLn("<FONT COLOR=#7b3139><H1>Registration Success</H1></FONT>");
	webI.printLn("<B>" + username + ", your machine has been registered and you will have unrestricted access to the network shortly.</B><BR>");
	webI.printLn("<H3>Please wait while we update your information.  This process will ");
	webI.printLn("take approximately 60 seconds and a message will appear when it is complete.<BR>");
	webI.printLn("Please be patient...</H3>");
	webI.printLn("<B>-Progress-</B><BR>");
	webI.printLn("<IMG SRC=/images/progress_bar.gif ALIGN=TOP><BR>");
	webI.printLn("</CENTER>");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	webI.printLn("</FORM>");
	webI.printLn("</BODY>");
	webI.printLn("</HTML>");
	exit(0);
}

void showHTMLregFinishedPage(cgiInterface &webI)
{
	// Show the finished page
	webI.printHeaderContentType("text/html");
	webI.printLn("<HTML>");
	webI.printLn("<HEAD>");
	webI.printLn("<TITLE>Online Machine Registration</TITLE>");
	webI.printLn("</HEAD>");
	webI.printLn("<BODY TEXT=#000000 BGCOLOR=#ffffff LINK=#0000ee VLINK=#551a8b ALINK=#ff0000>");
	webI.printLn("<CENTER>");
	webI.printLn("<IMG SRC=/images/resnetlogo.gif ALT=\"UPS ResNet\" ALIGN=TEXTTOP>");
	webI.printLn("</CENTER>");
	webI.printLn("<CENTER>");
	webI.printLn("<TABLE WIDTH=500>");
	webI.printLn("<TR><TD>");
	webI.printLn("<CENTER>");
	webI.printLn("<FONT COLOR=#7b3139><H1>Registration Complete</H1></FONT>");
	webI.printLn("<B>Your ResNet information has been updated and you now have full ");
	webI.printLn("access to the campus network and the internet.<BR><BR>");
	webI.printLn("<FONT COLOR=#7b3139>You will now need to restart your computer for changes to take effect.</FONT><BR><BR>");
	webI.printLn("The computer you are currently on has been registered specifically ");
	webI.printLn("to you. Should you need to register additional computers, you will need ");
	webI.printLn("to contact the ResNet office. Additionally, should you experience problems ");
	webI.printLn("with your ResNet account or service, please contact our office by calling ");
	webI.printLn("x8570, Emailing <A HREF=mailto:resnet@ups.edu>resnet@ups.edu</A> or stop by McIntyre Hall 011J.</B>");
	webI.printLn("</CENTER>");
	webI.printLn("</TD></TR>");
	webI.printLn("</TABLE>");
	webI.printLn("</CENTER>");
	webI.printLn("</BODY>");
	webI.printLn("</HTML>");
	exit(0);
}

#endif // defined( HTML_REG_PAGES_H )

